## $Id: utils.py 15103 2018-08-10 09:02:28Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Customize general helper utilities for Kofa.
"""
from copy import deepcopy
from kofacustom.nigeria.utils.utils import NigeriaKofaUtils

class CustomKofaUtils(NigeriaKofaUtils):
    """A collection of methods subject to customization.
    """

    APP_CATS_DICT = {
        'basic': 'Basic Application',
        'no': 'no application',
        'ft': 'Full Time Courses',
        'pt': 'Part Time Courses',
        'pre': 'Pre-Degree Studies',
        'ct': 'Certificate Programmes',
        }

    PAYMENT_CATEGORIES = {
        'schoolfee': 'Tuition/Exams Fee and Student Union Dues',
        'clearance': 'Acceptance Fee',
        'bed_allocation': 'Accommodation Booking Fee',
        'hostel_maintenance': 'Hostel Maintenance Fee',
        'application': 'Application Fee',
        'ict_entre': 'ICT and Entrepreneur Fee',
        'logbook_combo': 'Logbook Combo Fee',
        'siwess_combo': 'SIWESS Combo Fee',
        'transcript': 'Transcript Fee',
        'certificate': 'Certificate Fee',
        'certificate_confirm': 'Certificate Confirmation Fee',
        'late_registration': 'Late Course Registration Fee',
        'final_clearance': 'Final Clearance Fee',
        }

    SELECTABLE_PAYMENT_CATEGORIES = deepcopy(PAYMENT_CATEGORIES)

    BALANCE_PAYMENT_CATEGORIES = {
        'schoolfee': 'Tuition/Exams Fee and Student Union Dues',
        'ict_entre': 'ICT and Entrepreneur Fee',
        'certificate_confirm': 'Certificate Confirmation Fee',
        'final_clearance': 'Final Clearance Fee',
        }

    REPORTABLE_PAYMENT_CATEGORIES = {
        'schoolfee': 'Tuition Exams Fee',
        'clearance': 'Accept. Fee',
        'hostel_maintenance': 'Hostel Maint. Fee',
        'ict_entre': 'ICT Entrepr. Fee',
        'logbook_combo': 'Logbook Combo Fee',
        'siwess_combo': 'SIWESS Combo Fee',
        'certificate': 'Cert. Fee',
        'certificate_confirm': 'Cert. Confirm. Fee',
        'late_registration': 'Late Course Registr. Fee',
        'final_clearance': 'Final Clearance Fee',
        }

    STUDY_MODES_DICT = {
        'ug_ft': 'Undergraduate Full Time (not used in EdoPoly)',
        'nd_ft': 'National Diploma Full Time',
        'nd_pt': 'National Diploma Part Time',
        'hnd_ft': 'Higher National Diploma Full Time',
        'hnd_pt': 'Higher National Diploma Part Time',
        'ct': 'Certificate',
        'pre': 'Pre-Degree',
        'transfer': 'Transfer',
        'no': 'no application',
        }

    MODE_GROUPS = {
        'All': ('all',),
        'Undergraduate Full-Time': ('hnd_ft', 'nd_ft'),
        'Undergraduate Part-Time': ('hnd_pt', 'nd_pt'),
        #'Postgraduate Full-Time': ('pg_ft',),
        #'Postgraduate Part-Time': ('pg_pt',),
        }
